@@ -1,5 +1,5 @@
 package Pod::ProjectDocs::Doc;
-$Pod::ProjectDocs::Doc::VERSION = '0.43';
+$Pod::ProjectDocs::Doc::VERSION = '0.44';
 use strict;
 use warnings;
 
@@ -35,7 +35,7 @@ sub _set_relpath {
         $self->name( join "::", File::Spec->splitdir($relpath) );
     }
     else {
-        $self->name( join "-", File::Spec->splitdir($relpath) );
+        $self->name( join "/", File::Spec->splitdir($relpath) );
     }
     $self->relpath($relpath.".".$suffix.".html");
 }
